==> v4.0.2.zip: pkg-component-builder/README.md <==
# Component Builder Package (v4.0.2)

The Joomla Component Builder Package that bundles JCB Component and all the plugins and features available into one package for easy install and update of your JCB system for Joomla 4.

## Details

- Packager: [Vast Development Method](https://dev.vdm.io/)
- Author: [Llewellyn van der Merwe](https://io.vdm.dev/)
- Creation Date: August 2024
- Max Joomla Version: J4.4
- Minimum Joomla Version: J4.3

## Extensions

- [joomla/Component-Builder](https://git.vdm.dev/joomla/Component-Builder) [4.x](https://git.vdm.dev/joomla/Component-Builder/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuilderadminheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderadminheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildercomponentdashboardheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentdashboardheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentdashboardheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildercomponentheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildercustomadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercustomadminheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildercustomadminheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderfieldorderingtabs](https://git.vdm.dev/joomla/plg_content_componentbuilderfieldorderingtabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderfieldorderingtabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderlanguagetabs](https://git.vdm.dev/joomla/plg_content_componentbuilderlanguagetabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderlanguagetabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderprivacytabs](https://git.vdm.dev/joomla/plg_content_componentbuilderprivacytabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderprivacytabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildersiteheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildersiteheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildersiteheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderdynamicgetheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuilderdynamicgetheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderdynamicgetheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderactionlogcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderactionlogcompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderactionlogcompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderexportcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderexportcompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderexportcompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderfieldorderingcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderfieldorderingcompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderfieldorderingcompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderheaderscompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderheaderscompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderheaderscompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderlanguagepackaging](https://git.vdm.dev/joomla/plg_extension_componentbuilderlanguagepackaging) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderlanguagepackaging/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderpowersautoloadercompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderpowersautoloadercompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderpowersautoloadercompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderprivacycompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderprivacycompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderprivacycompiler/archive/4.x.zip)
> 4.x

### Copyright (2015)
> Copyright (C) 2015 Llewellyn van der Merwe. All rights reserved.
### License
> GNU General Public License version 2; see LICENSE

==> v4.0.3.zip: pkg-component-builder/README.md <==
# Component Builder Package (v4.0.3)

The Joomla Component Builder Package that bundles JCB Component and all the plugins and features available into one package for easy install and update of your JCB system for Joomla 4.

## Details

- Packager: [Vast Development Method](https://dev.vdm.io/)
- Author: [Llewellyn van der Merwe](https://io.vdm.dev/)
- Creation Date: September 2024
- Max Joomla Version: J4.4
- Minimum Joomla Version: J4.3

## Extensions

- [joomla/Component-Builder](https://git.vdm.dev/joomla/Component-Builder) [4.x](https://git.vdm.dev/joomla/Component-Builder/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuilderadminheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderadminheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildercomponentdashboardheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentdashboardheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentdashboardheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildercomponentheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildercomponentheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildercustomadminheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildercustomadminheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildercustomadminheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderfieldorderingtabs](https://git.vdm.dev/joomla/plg_content_componentbuilderfieldorderingtabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderfieldorderingtabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderlanguagetabs](https://git.vdm.dev/joomla/plg_content_componentbuilderlanguagetabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderlanguagetabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderprivacytabs](https://git.vdm.dev/joomla/plg_content_componentbuilderprivacytabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderprivacytabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuildersiteheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuildersiteheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuildersiteheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_content_componentbuilderdynamicgetheaderstabs](https://git.vdm.dev/joomla/plg_content_componentbuilderdynamicgetheaderstabs) [4.x](https://git.vdm.dev/joomla/plg_content_componentbuilderdynamicgetheaderstabs/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderactionlogcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderactionlogcompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderactionlogcompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderexportcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderexportcompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderexportcompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderfieldorderingcompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderfieldorderingcompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderfieldorderingcompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderheaderscompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderheaderscompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderheaderscompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderlanguagepackaging](https://git.vdm.dev/joomla/plg_extension_componentbuilderlanguagepackaging) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderlanguagepackaging/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderpowersautoloadercompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderpowersautoloadercompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderpowersautoloadercompiler/archive/4.x.zip)
> 4.x
- [joomla/plg_extension_componentbuilderprivacycompiler](https://git.vdm.dev/joomla/plg_extension_componentbuilderprivacycompiler) [4.x](https://git.vdm.dev/joomla/plg_extension_componentbuilderprivacycompiler/archive/4.x.zip)
> 4.x

### Copyright (2015)
> Copyright (C) 2015 Llewellyn van der Merwe. All rights reserved.
### License
> GNU General Public License version 2; see LICENSE
